@@ -6,8 +6,7 @@ class FileUtils:
     @staticmethod
     def absPath(path):
         # this function should be the abs path relative to the project root
-        basePath = os.path.dirname(os.path.dirname(
-            os.path.dirname(os.path.abspath(__file__))))
+        basePath = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
         return os.path.join(basePath, path)
 
     @staticmethod
